@@ -1,4 +1,7 @@
-#ifdef PYTHON_IN_R_NO_EXPLICIT_LINKING
+#ifndef PYTHON_IN_R_FUNCTIONS
+#define PYTHON_IN_R_FUNCTIONS
+int ISO_C_forbids_an_empty_translation_unit;
+#if ( defined(PY_EXPERIMENTAL) && defined(PYTHON_IN_R_NO_EXPLICIT_LINKING) )
 #include "PythonFunctions.h"
 
 /* --------------------------------------------------------------------------  \
@@ -111,9 +114,5 @@ PyMODINIT_FUNC python_in_r_init_methods(void){
     (void) Py_InitModule("PythonInR", PythonInRMethods);
 }
 
-#else
-#ifndef PYTHON_EXPLICIT_LINKING
-#define PYTHON_EXPLICIT_LINKING
-int ISO_C_forbids_an_empty_translation_unit;
 #endif
 #endif
